emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/lisp/log-view.el


From: Stefan Monnier
Subject: [Emacs-diffs] Changes to emacs/lisp/log-view.el
Date: Mon, 09 Jan 2006 18:20:21 +0000

Index: emacs/lisp/log-view.el
diff -u emacs/lisp/log-view.el:1.27 emacs/lisp/log-view.el:1.28
--- emacs/lisp/log-view.el:1.27 Fri Dec 23 21:49:32 2005
+++ emacs/lisp/log-view.el      Mon Jan  9 18:20:21 2006
@@ -27,7 +27,7 @@
 
 ;; Major mode to browse revision log histories.
 ;; Currently supports the format output by:
 ;;  RCS, SCCS, CVS, Subversion.
 
 ;; Examples of log output:
 
@@ -50,6 +50,22 @@
 
 ;;;; Subversion:
 
+;;;; Darcs:
+
+;; Changes to darcsum.el:
+;; 
+;; Mon Nov 28 15:19:38 GMT 2005  Dave Love <address@hidden>
+;;   * Abstract process startup into darcsum-start-process.  Use TERM=dumb.
+;;   TERM=dumb avoids escape characters, at least, for any old darcs that 
+;;   doesn't understand DARCS_DONT_COLOR & al.
+;; 
+;; Thu Nov 24 15:20:45 GMT 2005  Dave Love <address@hidden>
+;;   * darcsum-mode-related changes.
+;;   Don't call font-lock-mode (unnecessary) or use-local-map (redundant).
+;;   Use mode-class 'special.  Add :group.
+;;   Add trailing-whitespace option to mode hook and fix
+;;   darcsum-display-changeset not to use trailing whitespace.
+
 ;;; Todo:
 
 ;; - add ability to modify a log-entry (via cvs-mode-admin ;-)
@@ -114,13 +130,22 @@
 
 (defconst log-view-file-re
   (concat "^\\(?:Working file: \\(.+\\)"                ;RCS and CVS.
-          "\\|SCCS/s\\.\\(.+\\):"                       ;SCCS.
+          "\\|\\(?:SCCS/s\\.\\|Changes to \\)\\(.+\\):" ;SCCS and Darcs.
          "\\)\n"))                   ;Include the \n for font-lock reasons.
 
 (defconst log-view-message-re
   (concat "^\\(?:revision \\([.0-9]+\\)\\(?:\t.*\\)?" ; RCS and CVS.
           "\\|r\\([0-9]+\\) | .* | .*"                ; Subversion.
           "\\|D \\([.0-9]+\\) .*"                     ; SCCS.
+          ;; Darcs doesn't have revision names.  VC-darcs uses patch names
+          ;; instead.  Darcs patch names are hashcodes, which do not appear
+          ;; in the log output :-(, but darcs accepts any prefix of the log
+          ;; message as a patch name, so we match the first line of the log
+          ;; message.
+          ;; First loosely match the date format.
+          (concat "\\|[^ \n].*[^0-9\n][0-9][0-9]:[0-9][0-9][^0-9\n].*[^ \n]"
+                  ;;Email of user and finally Msg, used as revision name.
+                  "  address@hidden(?:  \\* \\(.*\\)\\)?")
           "\\)$"))
 
 (defconst log-view-font-lock-keywords
@@ -27,7 +27,7 @@
 ;; Major mode to browse revision log histories.
 ;; Currently supports the format output by:
-;;  RCS, SCCS, CVS, Subversion.
+;;  RCS, SCCS, CVS, Subversion, and DaRCS.
 
 ;; Examples of log output:




reply via email to

[Prev in Thread] Current Thread [Next in Thread]